

"""This module offers a function to know something about sandorm 
"""

def whoissandorm():
  """ Here you get to know the secret.
  """
  print("Sandorm is a worm. It's the nickname for Chris in Berlin")
  


