from distutils.core import setup

setup(
  name = 'sandorm',
  version = '1.0.1',
  py_modules = ['sandorm'],
  author = 'christian',
  author_email = 'hoefig@harung.de',
  url = 'http://www.harung.de',
  description = 'print sandorm information'
)
